initializeCamera method
void
initializeCamera()
Initialize the camera and start the face detection image stream.
Implementation
void initializeCamera() {
if (_isClosed) return;
_onInitializeCam();
}
Initialize the camera and start the face detection image stream.
void initializeCamera() {
if (_isClosed) return;
_onInitializeCam();
}