onFaceSnapshot property
Callback invoked with the list of detected faces each time a face is found.
Implementation
final void Function(List<Face>)? onFaceSnapshot;
Callback invoked with the list of detected faces each time a face is found.
final void Function(List<Face>)? onFaceSnapshot;