LivenessResult class

Result of a liveness check.

Constructors

LivenessResult({required bool isLive, String? reason})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isLive bool
Whether the face belongs to a live person.
final
reason String?
Human-readable reason when isLive is false.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited