initializingCameraScreen property
Custom loading screen shown while the camera is initializing.
Implementation
final Widget? initializingCameraScreen;
Custom loading screen shown while the camera is initializing.
final Widget? initializingCameraScreen;