noCameraDetectedErrorScreen property
Custom error widget shown when no camera is detected on the device.
Implementation
final Widget? noCameraDetectedErrorScreen;
Custom error widget shown when no camera is detected on the device.
final Widget? noCameraDetectedErrorScreen;