FaceDetectionUnverified class final
A face was detected but did not match any enrolled template.
- Inheritance
-
- Object
- FaceDetectionState
- FaceDetectionUnverified
Constructors
- FaceDetectionUnverified({double confidence = 0.0})
-
const
Properties
- confidence → double
-
Similarity score from the best match attempt (0.0–1.0).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited