FaceTemplateStore class abstract

Abstract storage interface for face templates.

Implement this to persist templates with your preferred backend (SQLite, Hive, flutter_secure_storage, etc.).

Implementers

Constructors

FaceTemplateStore()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<void>
Delete all stored templates.
delete(String id) Future<void>
Delete a template by id.
get(String id) Future<FaceTemplate?>
Retrieve a template by id, or null if not found.
getAll() Future<List<FaceTemplate>>
Retrieve all stored templates.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(FaceTemplate template) Future<void>
Save or update a template.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited