FaceVerificationProvider class abstract

Abstract interface for face verification.

Implement this to provide custom verification backends (cloud APIs, different ML models, etc.). Use LocalFaceVerificationProvider for the built-in on-device implementation.

Implementers

Constructors

FaceVerificationProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkLiveness(Face face) Future<LivenessResult>
Check a face for liveness (anti-spoofing).
clearAll() Future<void>
Delete all enrolled templates.
deleteTemplate(String id) Future<void>
Delete an enrolled template by ID.
enroll(String label, List<Face> samples) Future<FaceTemplate>
Enroll a new face from multiple sample captures.
listTemplates() Future<List<FaceTemplate>>
List all enrolled templates.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
verify(Face face) Future<FaceVerificationResult>
Verify a detected face against enrolled templates.

Operators

operator ==(Object other) bool
The equality operator.
inherited